<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="fr" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Catégorie :</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Démarrer le torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Ne pas vérifier les données du torrent</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Créer un sous-dossier</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Mode de gestion des torrents</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Toutes</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Non catégorisé</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Ajouter catégorie ...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Retirer catégorie</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Retirer catégories inutilisées</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Relancer torrents</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Mettre en pause les torrents</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Supprimer torrents</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nouvelle Catégorie</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Editer catégorie...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Quitter qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Un seul lien par ligne</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>La limite globale pour la vitesse d'envoi doit être supérieure à 0 ou désactivée.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>La limite globale de vitesse de téléchargement doit être supérieure à 0 ou désactivée.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>La limite alternative pour la vitesse d'envoi doit être supérieure à 0 ou désactivée.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>La limite alternative de vitesse de téléchargement doit être supérieure à 0 ou désactivée.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Le nombre maximum de téléchargements actifs doit être supérieur à -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Le nombre maximum d'envois actifs doit être supérieur à -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Le nombre maximum de torrents actifs doit être supérieur à -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Le nombre maximum de connexions doit être supérieur à 0 ou désactivé.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Le nombre maximum de connexions par torrent doit être supérieur à 0 ou désactivé.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Le nombre maximum de réceptionnaires par torrent doit être supérieur à 0 ou désactivé.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Impossible de sauvegarder les préférences, qBittorrent est probablement injoignable.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC : #qbittorrent sur Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Le ratio doit être compris entre 0 et 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Le temps de partage doit être compris entre 0 et 525600 minutes.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Le port utilisé pour les connexions entrantes doit être compris entre 1 et 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Le port utilisé pour l'interface Web doit être compris entre 1024 et 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Impossible de se connecter, qBittorrent est probablement inaccessible.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Nom d'utilisateur ou mot de passe invalide.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d'utilisateur</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Identifiant</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Auteurs originaux</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Téléverser des torrents</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Sauvegarder les fichiers dans :</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie :</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Entrez le dossier ici</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Plus d'informations</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Information sur les certificats</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Dossier d'enregistrement</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Limiter la vitesse d'envoi…</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Limiter la vitesse de téléchargement…</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Renommer le torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Autre...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Lundi</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Mardi</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Mercredi</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Jeudi</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Vendredi</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Samedi</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dimanche</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Se déconnecter</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Télécharger les torrents depuis leurs URLs ou liens Magnet</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Transférer un torrent local</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Voulez-vous vraiment supprimer les torrents sélectionnés de la liste de transfert ?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Le logiciel qBittorrent n'est pas accessible</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Le nombre global de réceptionnaires doit être supérieure à 0 ou désactivée.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Nom de catégorie invalide :\nMerci ne pas utiliser de caractères spéciaux dans le nom de catégorie.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Impossible de créer la catégorie</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>La limite de vitesse d'envoi doit être supérieure à 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edition</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Espace libre : %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Le temps limite d'inactivité d'un torrent doit être supérieur à 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Gestion des enregistrements</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>La limite de vitesse de téléchargement doit être supérieure à 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent a été fermé</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Édition</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Outils</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Options...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Priorité minimale</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Priorité maximale</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Diminuer la priorité</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Augmenter la priorité</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Barre d'outils</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barre de statut</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Vitesse dans le titre de la fenêtre</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Faire un don !</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Tout Démarrer</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiques</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Mettre en pause</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Tout mettre en pause</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Ajouter un fichier torrent…</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Documentation</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Ajouter lien vers un torrent…</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Limite globale de la vitesse d'envoi</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Limite globale de la vitesse de téléchargement</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Êtes-vous sûr de vouloir quitter qBittorrent ?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[R : %1, E : %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Limites alternatives de vitesse</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Moteur de recherche</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtrer la liste des torrents…</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Transferts</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Vitesse</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Interface web</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Langue de l'interface utilisateur :</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Notification par e-mail en fin de téléchargement</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Lancer un programme externe à la fin d'un téléchargement</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Filtrage IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Planifier l'utilisation des limites alternatives de vitesses</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Priorisation des torrents</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Partager les torrents tant que la durée est inférieure à</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Ajouter automatiquement ces trackers aux nouveaux téléchargements :</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Interface Web de l'utilisateur (contrôle distant)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>Adresse IP :</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Nom de Domaine :</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Utiliser HTTPS au lieu de HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Désactiver l'authentification pour localhost</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Désactiver l'authentification pour les IP des clients de sous domaine autorisés</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Mettre à jour mon nom de domaine dynamique</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Conserver les torrents incomplets dans :</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Copier les fichiers .torrent dans :</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Copier les fichiers .torrent des téléchargements terminés dans :</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Pré-allouer l'espace disque pour tous les fichiers</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Ajouter l'extension .!qB aux noms des fichiers incomplets</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Ajouter automatiquement les torrents présents dans :</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Serveur SMTP :</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Ce serveur nécessite une connexion sécurisée (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Authentification</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d'utilisateur :</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Protocole permis :</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP et μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Port d'écoute</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Port pour les connexions entrantes :</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Utiliser la redirection de port sur mon routeur via UPnP / NAT-PMP</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Utiliser un port différent à chaque démarrage</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Limites de connexions</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Nombre maximum de connexions par torrent :</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Nombre maximum global de connexions :</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Nombre maximum de réceptionnaires par torrent :</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Nombre global maximum de réceptionnaires :</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Serveur mandataire (proxy)</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type :</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Aucun)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Hôte :</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port :</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Utiliser le proxy pour se connecter aux clients</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Les connexions désactivées ne sont pas supportées par les proxys.</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Utiliser le proxy seulement pour les torrents</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Chemin du filtre (.dat, .p2p, .p2b) :</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Adresses IP bannies manuellement...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Appliquer aux trackers</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Limites de vitesse globales</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Envoi :</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Téléchargement :</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Limites de vitesse alternatives</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Depuis :</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Vers :</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Quand :</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Tous les jours</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Jours ouvrés</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Week-ends</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Paramètres des limites de vitesse</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Appliquer les limites de vitesse au surplus généré par le protocole</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Appliquer les limites de vitesse au protocole µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Vie privée</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Activer DHT (réseau décentralisé) pour trouver plus de clients</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Activer l'échange de clients (PeX) avec les autres clients</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Activer la recherche de clients locaux pour trouver plus de clients</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Mode de cryptage:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Chiffrement préféré</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Chiffrement requis</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Chiffrement désactivé</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Activer le mode anonyme</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Nombre maximum de téléchargements actifs :</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Nombre maximum d'envois actifs :</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Nombre maximum de torrents actifs :</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Ne pas compter les torrents lents dans ces limites</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Limitation du ratio de partage</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Partager les torrents tant que le ratio est inférieur à</translation>
    </message>
    <message>
        <source>then</source>
        <translation>puis</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Les mettre en pause</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Les supprimer</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Utiliser la redirection de port sur mon routeur via UPnP / NAT-PMP</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certificat :</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Clé :</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Créer un compte</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Nom de domaine :</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Paramètres supportés (sensible à la casse) :</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N : Nom du torrent</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L : Catégorie</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G: Tags (séparés par des virgules)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F : Chemin vers le contenu (même chemin que le chemin racine pour les torrents composés de plusieurs fichiers)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Root path (first torrent subdirectory path)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Save path</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C : Nombre de fichiers</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z : Taille du torrent (en octets)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T : Tracker actuel</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I : Hachage d'information</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Encapsuler le paramètre entre guillemets pour éviter que le texte soit coupé en espace blanc (ex., "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Le nom d'utilisateur pour l'interface Web doit être au moins de 3 caractères de long.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Le mot de passe pour l'interface Web doit être au moins de 6 caractères de long.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutes</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Activer la protection contre le clickjacking</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Activer la protection contre les fausses requêtes croisées de site (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Supprimer ultérieurement les fichers .torrent</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Limite de vitesse de téléchargement :</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Limite de vitesse d'envoi :</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Changer le mot de passe</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Utiliser l'interface Web alternative</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Chemin de sauvegarde par défaut :</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>L'emplacement des fichiers pour l'interface Web alternative ne peut pas être vide.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Ne pas démarrer automatiquement le téléchargement</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Basculer le torrent en mode manuel</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Lorsque la catégorie du Torrent change :</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Déplacer les torrents affectés</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Appliquer les limites de vitesse aux clients locaux</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 pour aucune limite</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Déplacer le torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Lorsque le chemin d'enregistrement par défaut change :</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Activer la validation des entêtes de l'hôte</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sécurité</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Lorsque le chemin d'enregistrement de catégorie change :</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Créer un sous-dossier pour les torrents avec plusieurs fichiers</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>secondes</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Basculer les torrents affectés en mode manuel</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Emplacement des fichiers :</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Temps limite d'inactivité d'un torrent :</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Mode par défaut de gestion des torrents</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>A l'ajout d'un torrent</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Indicateurs</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Logiciel</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Progression</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Vitesse DL</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Vitesse UP</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Téléchargé</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Envoyé</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Pertinence</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Fichiers</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Pays</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normale</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Haute</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maximale</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Trackers</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Clients</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Sources HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Contenu</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Téléchargé :</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transfert</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Actif pendant :</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Temps restant :</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Envoyé :</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Sources :</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Vitesse de téléchargement :</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Vitesse d'émission :</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Clients :</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Limite de téléchargement :</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Limite d'envoi :</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Gaspillé :</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Connexions :</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informations</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Commentaire :</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Ratio de partage :</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Annoncer dans :</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Dernière fois vu complet :</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Taille totale :</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Morceaux :</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Créé par :</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Ajouté le :</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Complété le :</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Créé le :</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Hachage du torrent :</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Chemin de sauvegarde :</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Jamais</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 × %2 (a %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 cette session)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 maximum)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 total)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 en moyenne)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Limite de téléchargement :</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Limite d'envoi :</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Répertoire surveillé</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Remplacer l'emplacement de sauvegarde</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Répertoire surveillé</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Emplacement de sauvegarde par défaut</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>Kio/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistiques</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Statistiques utilisateur</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Statistiques du tampon</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Succès de tampon en lecture :</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Temps moyen passé en file d'attente :</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Clients connectés :</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Total du ratio de partage :</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Total téléchargé :</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Session surplus téléchargé :</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Total envoyé :</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Taille totale du tampon :</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Statistiques de performance</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Actions d'E/S en file d'attente :</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Surcharge du tampon d'écriture :</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Surcharge du tampon de lecture :</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Taille totale des fichiers en file d'attente :</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT : %1 nœuds</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Tous (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Téléchargement (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>En Partage (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Terminés (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Démarrés (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>En Pause (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Actifs (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inactifs (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Erreur (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Tous (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Téléchargement (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>En Partage (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Terminés (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>En Pause (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Démarrés (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Actifs (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inactifs (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Erreur (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progression</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Priorité de téléchargement</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Restant</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Disponibilité :</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Taille</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Progression</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Sources</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Clients</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Vitesse DL</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Vitesse UP</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Ratio</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Temps restant</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Catégorie</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Ajouté le</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Terminé le</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Limite réception</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Limite envoi</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Téléchargé</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Envoyé</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Téléchargement de la session</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Émission de la session</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Restant</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Actif pendant</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Chemin de sauvegarde</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Terminé</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Limite de ratio</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Dernière fois vu complet</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Dernière activité</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Taille totale</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Clients</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Message</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Téléchargé</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL du tracker :</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Mise à jour...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Fonctionne</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Pas encore contacté</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Sources</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Ne fonctionne pas</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Copier l'URL du tracker</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Ajouter un nouveau tracker…</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Modifier l'URL du tracker...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Modification du tracker</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Téléchargeurs</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Supprimer le tracker</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Fenêtre d'ajout de trackers</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Liste des trackers à ajouter (un par ligne) :</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>il y a %1</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Attribution</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pause</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Déplacement</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Partage</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Partage</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>En attente</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Téléchargement</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Téléchargement des métadonnées</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Vérification</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Fichiers manquants</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Attente de vérification</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Téléchargement</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Vérification des données de reprise</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>En attente</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Catégories</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Limitation de la vitesse de téléchargement</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Limitation de la vitesse d'émission</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Forcer la reprise</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Mettre en pause</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Limiter le ratio de partage…</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Limiter la vitesse d'envoi…</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Limiter la vitesse de téléchargement…</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Déplacer vers le haut</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Déplacer vers le bas</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Déplacer tout en haut</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Déplacer tout en bas</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Chemin de sauvegarde…</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Copier nom</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Copier le hash</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Télécharger premières et dernières pièces en premier</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Gestion de torrent automatique</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Catégorie</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nouvelle…</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Réinitialiser</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorité</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Forcer une revérification</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Copier le lien magnet</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Mode de super-partage</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Renommer…</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Téléchargement séquentiel</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Forcer une revérification</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nouvelle Catégorie</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nouveau nom</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Choisir l'emplacement</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Forcer une réannonce</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Editer catégorie</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Chemin d'enregistrement</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Limitation du ratio de partage</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Utiliser les limites globales de partage</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Ne pas limiter le partage</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Limiter le partage à</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>ratio</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutes</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Un client avancé BitTorrent programmé en C++, basé sur l'outil Qt et libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Page d'accueil :</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forum :</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Suivi de Bogues :</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Confirmation de suppression</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Supprimer également les fichiers sur le disque</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Confirmation de suppression - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Télécharger depuis des URLs</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Ajouter liens de torrents</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>Oct</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>Kio</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>Mio</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>Gio</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>Tio</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>Pio</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>Eio</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1j %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Inconnue</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1min</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1min</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Chemin d'enregistrement vide</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Dossier des plugins :</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL ou dossier local</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Installer plugin</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Sources :</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Tous les plugins</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Taille :</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Recherche</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Recherche de plugins</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Toutes catégories</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Rechercher dans :</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Copier l'URL de la page de description</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Aller à la page de description</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Résultats</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtrer</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Noms de torrent seulement</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Uniquement activé(s)</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>sur</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Partout</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Désinstaller</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Installer nouveau plugin</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Vous pouvez obtenir le nouveau moteur de recherche de plugins ici :</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Plugins de recherche installés :</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Activé</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Avertissement : assurez-vous de respecter les lois de votre pays au sujet du droit d'auteur lorsque vous téléchargerez des torrents depuis n'importe lequel de ces moteurs de recherche.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Rechercher mises à jour</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Recherche de plugins</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Téléchargeurs</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Moteur de recherche</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Partageurs</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Activé</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
</TS>